@@ -32,7 +32,7 @@ def test_explanation(explanation: str, target_class: int, x: torch.Tensor, y: to
             explanation = explanation.replace(concept_name, f"feature{i:010}")
 
     if explanation == '':
-        local_predictions = [torch.tensor(np.empty_like(y))]
+        local_predictions = [torch.empty_like(y)]
         predictions = torch.cat(local_predictions).eq(target_class).cpu().detach().numpy()
         accuracy = 0.0
         return accuracy, torch.stack(local_predictions, dim=0).sum(dim=0) > 0 if give_local else predictions
