@@ -6,7 +6,7 @@ import torch
 class TestTemplateObject(unittest.TestCase):
     def test_relunets_pruning(self):
         import numpy as np
-        from deep_logic.utils.relunn import get_reduced_model
+        from deep_logic.utils.relu_nn import get_reduced_model
         from deep_logic.utils.base import validate_network, validate_data
         from deep_logic.logic import explain_local, combine_local_explanations, explain_global, \
             test_explanation, replace_names
@@ -53,7 +53,7 @@ class TestTemplateObject(unittest.TestCase):
             optimizer.step()
 
             if epoch > 500 and need_pruning:
-                dl.utils.relunn.prune_features(model, n_classes)
+                dl.utils.relu_nn.prune_features(model, n_classes)
                 need_pruning = False
 
             # compute accuracy
@@ -101,7 +101,7 @@ class TestTemplateObject(unittest.TestCase):
 
     def test_relunets_pruning_binary(self):
         import numpy as np
-        from deep_logic.utils.relunn import get_reduced_model
+        from deep_logic.utils.relu_nn import get_reduced_model
         from deep_logic.utils.base import validate_network, validate_data
         from deep_logic.logic import explain_local, combine_local_explanations, explain_global, \
             test_explanation, replace_names
@@ -146,7 +146,7 @@ class TestTemplateObject(unittest.TestCase):
             optimizer.step()
 
             if epoch > 500 and need_pruning:
-                dl.utils.relunn.prune_features(model, n_classes)
+                dl.utils.relu_nn.prune_features(model, n_classes)
                 need_pruning = False
 
             # compute accuracy
@@ -174,7 +174,7 @@ class TestTemplateObject(unittest.TestCase):
         simplified_formula = simplify_formula(explanation, model, x, y.squeeze(), x[1], y[1])
         simplified_formula = replace_names(simplified_formula, concept_names=['x1', 'x2', 'x3', 'x4'])
         print(simplified_formula)
-        assert simplified_formula == 'x2'
+        assert simplified_formula == '~x1 & x2'
 
         for target_class in range(n_classes):
             global_explanation = explain_global(model, n_classes,
@@ -192,7 +192,7 @@ class TestTemplateObject(unittest.TestCase):
 
     def test_relunets_no_pruning(self):
         import numpy as np
-        from deep_logic.utils.relunn import get_reduced_model
+        from deep_logic.utils.relu_nn import get_reduced_model
         from deep_logic.utils.base import validate_network, validate_data
         from deep_logic.logic import explain_local, combine_local_explanations
         import deep_logic as dl
@@ -255,7 +255,7 @@ class TestTemplateObject(unittest.TestCase):
 
     def test_relunets_no_bias(self):
         import numpy as np
-        from deep_logic.utils.relunn import get_reduced_model
+        from deep_logic.utils.relu_nn import get_reduced_model
         from deep_logic.utils.base import validate_network, validate_data
         from deep_logic.logic import explain_local, combine_local_explanations
         import deep_logic as dl
@@ -320,7 +320,7 @@ class TestTemplateObject(unittest.TestCase):
         import torch
         import numpy as np
         from deep_logic.utils.base import validate_network
-        from deep_logic.utils.sigmoidnn import prune_equal_fanin
+        from deep_logic.utils.psi_nn import prune_equal_fanin
         from deep_logic import logic
 
         torch.manual_seed(0)
@@ -374,7 +374,7 @@ class TestTemplateObject(unittest.TestCase):
         return
 
     def test_pruning(self):
-        from deep_logic.utils.sigmoidnn import prune_equal_fanin, validate_pruning
+        from deep_logic.utils.psi_nn import prune_equal_fanin, validate_pruning
 
         layers = [torch.nn.Linear(3, 4), torch.nn.Sigmoid(), torch.nn.Linear(4, 1), torch.nn.Sigmoid()]
         net = torch.nn.Sequential(*layers)
